@@ -1,14 +1,14 @@
 # From https://raw.githubusercontent.com/microsoft/pyright/main/packages/pyright-internal/src/localization/package.nls.en-us.json
 import re
 import textwrap
-from typing import NamedTuple
+from typing import NamedTuple, Dict, List
 
 import parse
 
 from nicepyright.utils import con
 
 
-def _get_message_parsers() -> dict[str, dict[str, parse.Parser]]:
+def _get_message_parsers() -> Dict[str, Dict[str, parse.Parser]]:
     raw_messages = {
         "Diagnostic": {
             "annotatedParamCountMismatch": "Parameter annotation count mismatch: expected {expected} but received {received}",
@@ -694,7 +694,7 @@ def _get_message_parsers() -> dict[str, dict[str, parse.Parser]]:
         },
     }
 
-    parsed_messages: dict[str, dict[str, parse.Parser]] = {}
+    parsed_messages: Dict[str, Dict[str, parse.Parser]] = {}
     for category, messages in raw_messages.items():
         cat = parsed_messages[category] = {}
         for name, message in messages.items():
@@ -714,7 +714,7 @@ def camel_case_to_snake_case(name: str) -> str:
     return re.sub(r"(?<!^)(?=[A-Z])", "_", name).lower()
 
 
-def split_camel_case_words(name: str) -> list[str]:
+def split_camel_case_words(name: str) -> List[str]:
     """Splits a camelCase string into words."""
     return re.findall(r".[^A-Z]*", name)
 
@@ -745,7 +745,7 @@ class ParsedDiagnosticAddendum(NamedTuple):
     result: parse.Result
 
     @property
-    def values(self) -> dict[str, str]:
+    def values(self) -> Dict[str, str]:
         return self.result.named
 
     @property
@@ -756,21 +756,20 @@ class ParsedDiagnosticAddendum(NamedTuple):
 class ParsedDiagnostic(NamedTuple):
     category: str
     result: parse.Result
-    addendums: list[ParsedDiagnosticAddendum]
+    addendums: List[ParsedDiagnosticAddendum]
 
     @property
     def category_text(self) -> str:
         return camel_case_to_capitalized_text(self.category)
 
     @property
-    def values(self) -> dict[str, str]:
+    def values(self) -> Dict[str, str]:
         return self.result.named
 
     def __rich_repr__(self) -> str:
         cat_str = camel_case_to_capitalized_text(self.category)
         results = [
-            f"{camel_case_to_capitalized_text(k)}: {v}"
-            for k, v in self.result.named.items()
+            f"{camel_case_to_capitalized_text(k)}: {v}" for k, v in self.result.named.items()
         ]
         results_str = textwrap.indent("\n".join(results), "  ")
         return f"{cat_str}:\n{results_str}"
@@ -792,9 +791,7 @@ def parse_message(message: str) -> ParsedDiagnostic:
     ]
     if len(parsed_diagnostics) == 0:
         con.log(f"Could not parse diagnostic: {diagnostic}", log_locals=True)
-        return ParsedDiagnostic(
-            "unknown", parse.parse("result: {mask}", "result: idk"), []
-        )  # todo
+        return ParsedDiagnostic("unknown", parse.parse("result: {mask}", "result: idk"), [])  # todo
     elif len(parsed_diagnostics) > 1:
         con.log(f"Could not parse diagnostic: {diagnostic}", log_locals=True)
 
